@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0402';
 
 use strictures 2;
 use curry;
@@ -100,7 +100,7 @@ has arp => (
 
 has arp_types => (
     is  => 'rw',
-    isa => sub { die 'Invalid rtc' unless ref($_[0]) eq 'Array::Circular' },
+    isa => sub { die 'Invalid controller' unless ref($_[0]) eq 'Array::Circular' },
     default => sub { Array::Circular->new(qw(up down random)) },
 );
 
@@ -300,7 +300,7 @@ MIDI::RtController::Filter::Tonal - Tonal RtController filters
 
 =head1 VERSION
 
-version 0.0400
+version 0.0402
 
 =head1 SYNOPSIS
 
@@ -308,16 +308,16 @@ version 0.0400
   use MIDI::RtController ();
   use MIDI::RtController::Filter::Tonal ();
 
-  my $rtc = MIDI::RtController->new(
+  my $controller = MIDI::RtController->new(
     input  => 'keyboard',
     output => 'usb',
   );
 
-  my $filter = MIDI::RtController::Filter::Tonal->new(rtc => $rtc);
+  my $filter = MIDI::RtController::Filter::Tonal->new(rtc => $controller);
 
-  $rtc->add_filter('pedal', note_on => $filter->curry::pedal_tone);
+  $controller->add_filter('pedal', note_on => $filter->curry::pedal_tone);
 
-  $rtc->run;
+  $controller->run;
 
 =head1 DESCRIPTION
 
@@ -548,11 +548,7 @@ time before being sent to a MIDI output.
 
 The F<eg/*.pl> program(s) in this distribution
 
-L<MIDI::RtController::Filter::Drums>
-
-L<MIDI::RtController::Filter::Math>
-
-L<MIDI::RtController::Filter::CC>
+L<curry>
 
 L<Array::Circular>
 
@@ -560,6 +556,8 @@ L<List::SomeUtils>
 
 L<List::Util>
 
+L<MIDI::RtController::Filter>
+
 L<MIDI::RtMidi::ScorePlayer>
 
 L<Moo>
@@ -574,6 +572,8 @@ L<Music::ToRoman>
 
 L<Music::VoiceGen>
 
+L<Types::Common::Numeric>
+
 L<Types::MIDI>
 
 L<Types::Standard>
